<#

	.SYNOPSIS
	Disables Exchange Admin Center access from the Internet and creates a new website for internal EAC access. The server requires a secondary IP address and a valid SSL certificate for the new website.

	Author/Copyright:	Jeff Guillet, MCSM|MVP - All rights reserved
	Email/Blog/Twitter:	jeff@expta.com | www.expta.com | @expta

	THIS CODE IS MADE AVAILABLE AS IS, WITHOUT WARRANTY OF ANY KIND. THE ENTIRE RISK OF THE USE OR THE RESULTS FROM THE USE OF THIS CODE REMAINS WITH THE USER.

	.NOTES
	Version 1.3, March 20, 2015

	Revision History
	---------------------------------------------------------------------
	1.0	Initial release
	1.1	Added error code exits; updated for non-standard Inetpub path
	1.2	Fixed errors and added enhancements (thanks Benoit Boudeville)
	1.3	Removed test server reference
	
	.DESCRIPTION
	This script performs the steps required to disable EAC access from the Internet, as described in the EHLO blog post listed below. The script creates and configures a new website and virtual directories on the Exchange 2013 server, binds the specified SSL certificate to the new website, and disables EAC access on the Default Web Site. The optional DisableFbaOnDefaultWebSite parameter will disable Forms Based Authentication on the Default Web Site. 
	
	This script should be run once on each server and after any Exchange 2013 Cumulative Update (CU) is applied.

	.PARAMETER NewWebsiteIP
	Specifies the IP address to use for the new website in IIS. This IP address must be configured on the server before running this script. It is recommended to add the new IP address to the existing NIC.

	.PARAMETER Thumbprint
	Specifies the thumbprint of the SSL certificate to use for the new website. The certificate name must match the FQDN used for the new website.

	.PARAMETER DisableEacOnDefaultWebSite
	If set to true, this setting will disable Exchange Admin Center access on the Default Web Site. Default is true.

	.PARAMETER DisableFbaOnDefaultWebSite
	If set to true, this setting will disable forms based authentication on the Default Web Site. Default is false.

	.LINK
	http://www.expta.com/2015/02/introducing-new-exchangewebsite-for.html

	.LINK
	http://blogs.technet.com/b/exchange/archive/2015/02/11/configuring-multiple-owa-ecp-virtual-directories-on-the-exchange-2013-client-access-server-role.aspx

	.EXAMPLE
	PS C:\>New-ExchangeWebsite.ps1 -NewWebsiteIP 10.1.20.35 -Thumbprint 663F465DE17FD039979B8CE769118FA2A5AF157D

	This command configures a new website named OWA_SECONDARY in IIS. It configures the website to use the IP address 10.1.20.35 and binds the SSL certificate with the specified thumbprint for HTTPS. It sets the necessary ACLs and copies all the required files and folders. Finally, it disables Exchange Admin Center access on the Default Web Site because that's the default setting and resets IIS.
    
    	.EXAMPLE
	PS C:\>New-ExchangeWebsite.ps1 -NewWebsiteIP 10.1.20.35 -Thumbprint 663F465DE17FD039979B8CE769118FA2A5AF157D -DisableFbaOnDefaultWebSite $false

	This command is almost the same as the command in the previous example, except it also disables Forms Based Authentication on the Default Web Site.

    	.EXAMPLE
	PS C:\>New-ExchangeWebsite.ps1 -NewWebsiteIP 10.1.20.35 -Thumbprint 663F465DE17FD039979B8CE769118FA2A5AF157D -DisableFbaOnDefaultWebSite $true -DisableEacOnDefaultWebSite $true

	This command is almost the same as the command in the previous example, except it does not disable Exchange Admin Center access on the Default Web Site.

#>

# Define the script parameters
Param (
	[Parameter( Mandatory=$true )]
	[ipaddress]$NewWebsiteIP,
	[Parameter( Mandatory=$true )]
	[string]$Thumbprint,
	[Parameter( Mandatory=$false )]
	[bool]$DisableEacOnDefaultWebSite = $True,
	[Parameter( Mandatory=$false )]
	[bool]$DisableFbaOnDefaultWebSite = $False
)

Process {
	# Get and set scripting environment and variables
	Write-Progress -Activity "Configuring EAC Virtual directory" -status "Prerequisite checks" -percentComplete 1
	$WarningPreference = "SilentlyContinue"
	$ErrorActionPreference = "SilentlyContinue"
	$Server = $env:ComputerName
	$WwwPath = (Get-ItemProperty HKLM:\SOFTWARE\Microsoft\InetStp).PathWWWRoot
	$SecondaryPath = $WwwPath.Substring(0, $WwwPath.IndexOf("\wwwroot")) + "\OWA_SECONDARY"
	$SystemDrive = $env:SystemDrive

	# Confirm the script is running on an Exchange 2013 server
	If ( -not ($ExInstall -like "*Exchange Server\V15\") ) {
		Write-Host "ERROR: Please run this script from an Exchange 2013 server." -Foregroundcolor Red
		Write-Host
		Exit 100
	}

	# Confirm this is a ClientAccess Server
	if (( -not ( Get-ExchangeServer ).ServerRole -like "*ClientAccess*" ) ) {
		Write-Host "ERROR: This server does not have the Client Access Server role installed." -Foregroundcolor Red
		Write-Host
		Exit 150
	}

	# Check that NewWebsiteIP is valid
	Write-Verbose "Checking validity of new website IP: $NewWebsiteIP..."
	$NewWebsiteIP = ([ipaddress]$NewWebsiteIP).IPAddressToString
	$IPAddresses = ( Get-WmiObject Win32_NetworkAdapterConfiguration -Filter "IPEnabled = True" | Where-Object { $_.ServiceName -eq "netvsc" } ).IPAddress
	$IP4Count = ($IPAddresses | where {$_ -like "*.*"}).Count
	if ( -not ( $IPAddresses -like $NewWebsiteIP ) ) {
       		Write-Host "ERROR: IP Address $NewWebsiteIP is not configured on this server." -Foregroundcolor Red
		Write-Host
		Exit 200
	}
	if ( $IP4Count -lt 2 ) {
       		Write-Host "ERROR: You must configure an additional IP address on this server for the new website." -Foregroundcolor Red
		Write-Host
		Exit 300
	}

	# Check for valid certificate on server
	Write-Verbose "Checking for valid certificate with thumbprint: $Thumbprint..."
	$ThumbprintOK = (Get-ExchangeCertificate -Server $Server $Thumbprint | Where {$_.Status -eq "Valid"}).Thumbprint
	If ( -not ( $ThumbPrintOK) ) {
        	Write-Host "ERROR: Certificate $Thumbprint is missing on server $Server." -Foregroundcolor Red
		Write-Host
		Get-ExchangeCertificate
		Exit 400
	}

	### Reinstallation ###
	# Remove existing OWA_SECONDARY vDirs, website, and folders if they exist
	$Uninstall = Test-Path $SecondaryPath
	If ( $Uninstall ) {
		Write-Verbose "Previous OWA_SECONDARY configuration detected."
		Write-Progress -Activity "Configuring EAC Virtual directory" -status "Removing previous OWA virtual directory installation" -percentComplete 4
		Write-Verbose "Removing existing $Server\owa (OWA_SECONDARY) virtual directory..."
		Remove-OWAVirtualDirectory -Identity "$Server\owa (OWA_SECONDARY)" -Confirm:$false | Out-Null
		Write-Progress -Activity "Configuring EAC Virtual directory" -status "Removing previous ECP virtual directory installation" -percentComplete 10
		Write-Verbose " Removing existing $Server\ecp (OWA_SECONDARY) virtual directory..."
		Remove-ECPVirtualDirectory -Identity "$Server\ecp (OWA_SECONDARY)" -Confirm:$false | Out-Null
	}
	If ( Get-Website -Name "OWA_SECONDARY" ) {
		Write-Progress -Activity "Configuring EAC Virtual directory" -status "Removing previous OWA_SECONDARY website" -percentComplete 15
		Write-Verbose "Removing existing OWA_SECONDARY website..."
		Remove-WebSite -Name "OWA_SECONDARY"
		#Invoke-Command -ScriptBlock {IISReset $Server /NoForce /Timeout:120}
		#Write-Host
	}
	If ( $Uninstall ) {
		Write-Progress -Activity "Configuring EAC Virtual directory" -status "Removing $SecondaryPath" -percentComplete 20
		Write-Verbose "Removing existing $SecondaryPath directory..."
		Remove-Item -Recurse -Force $SecondaryPath
	}
	
	# Create new OWA_SECONDARY directory
	Write-Progress -Activity "Configuring EAC Virtual directory" -status "Creating new OWA_SECONDARY directory" -percentComplete 25
	Write-Verbose "Creating new folder $SecondaryPath..."
	New-Item -Type Directory -Path $SecondaryPath | Out-Null

	# Create new OWA_SECONDARY website and configure bindings
	Write-Progress -Activity "Configuring EAC Virtual directory" -status "Creating new OWA_SECONDARY website" -percentComplete 30
	Write-Verbose "Creating new OWA_SECONDARY website..."
	New-Website -Name "OWA_SECONDARY" -Port 80 -IPAddress $NewWebsiteIP -PhysicalPath $SecondaryPath -ApplicationPool "MSExchangeOWAAppPool" | Out-Null
	Write-Progress -Activity "Configuring EAC Virtual directory" -status "Creating SSL bindings" -percentComplete 35
	Write-Verbose "Binding certificate to OWA_SECONDARY website and configuring HTTPS..."
	New-WebBinding -Name "OWA_SECONDARY" -IP $NewWebsiteIP -Port 443 -Protocol https | Out-Null
	Get-ChildItem cert:\LocalMachine\My | where { $_.Thumbprint -eq $CertThumbprint } | New-Item IIS:\SslBindings\$NewWebsiteIP!443 | Out-Null

	# Configure NTFS permissions on OWA_SECONDARY folder
	Write-Progress -Activity "Configuring EAC Virtual directory" -status "Configuring NTFS permissions" -percentComplete 40
	Write-Verbose "Configure NTFS permssions on OWA_SECONDARY folder..."
	$Acl = Get-ACL $SecondaryPath
	$AccessRule= New-Object System.Security.AccessControl.FileSystemAccessRule("BUILTIN\IIS_IUSRS","ReadAndExecute","ContainerInherit,Objectinherit","none","Allow")
	$Acl.AddAccessRule($AccessRule)
	Set-Acl $SecondaryPath $Acl

	# Copy wwwroot folder contents to OWA_SECONDARY folder
	Write-Progress -Activity "Configuring EAC Virtual directory" -status "Copying wwwroot content" -percentComplete 45
	Write-Verbose "Copying content from $WwwPath\* to $SecondaryPath..."
	Copy-Item -Path $WwwPath\* -Destination $SecondaryPath -Recurse -Force

	# Copy OWA and ECP folders and contents to OWA_SECONDARY folder
	Write-Progress -Activity "Configuring EAC Virtual directory" -status "Copying OWA content" -percentComplete 50
	Write-Verbose "Copying content from ..\FrontEnd\HttpProxy\owa to $SecondaryPath..."
	Copy-Item -Path $ExInstall\FrontEnd\HttpProxy\owa -Destination $SecondaryPath -Recurse -Force
	Write-Progress -Activity "Configuring EAC Virtual directory" -status "Copying ECP content" -percentComplete 55
	Write-Verbose "Copying content from ..\FrontEnd\HttpProxy\ecp to $SecondaryPath..."
	Copy-Item -Path $ExInstall\FrontEnd\HttpProxy\ecp -Destination $SecondaryPath -Recurse -Force

	# Create new OWA and ECP virtual directories
	Write-Progress -Activity "Configuring EAC Virtual directory" -status "Creating new OWA virtual directory" -percentComplete 60
	Write-Verbose "Creating new $Server\owa (OWA_SECONDARY) virtual directory..."
	$r = New-OwaVirtualDirectory -Server $Server -Role ClientAccess -WebSiteName "OWA_SECONDARY" -Path "$SecondaryPath\OWA"
	Write-Progress -Activity "Configuring EAC Virtual directory" -status "Creating new ECP virtual directory" -percentComplete 70
	Write-Verbose "Creating new $Server\ecp (OWA_SECONDARY) virtual directory..."
	$r = New-EcpVirtualDirectory -Server $Server -Role ClientAccess -WebSiteName "OWA_SECONDARY" -Path "$SecondaryPath\ECP"

	# Disable Exchange Admin Center on the Default Web Site (default = True)
	if ( $DisableEacOnDefaultWebSite ) {
		Write-Progress -Activity "Configuring EAC Virtual directory" -status "Disabling EAC on Default Web Site" -percentComplete 80
		Write-Verbose "Disabling Exchange Admin Center (EAC) on the Default Web Site..."
		Set-EcpVirtualDirectory -Identity "$Server\ecp (Default Web Site)" -AdminEnabled $false
	}

	# Disable FBA on the Default Web Site if selected (default = False)
	if ( $DisableFbaOnDefaultWebSite ) {
		Write-Progress -Activity "Configuring EAC Virtual directory" -status "Disabling FBA on OWA" -percentComplete 85
		Write-Verbose "Disabling Forms Based Authentication for OWA on the Default Web Site..."
		Set-OWAVirtualDirectory -Identity "$Server\owa (Default Web Site)" -FormsAuthentication $false -WindowsAuthentication $true
		Write-Progress -Activity "Configuring EAC Virtual directory" -status "Disabling FBA on ECP" -percentComplete 90
		Write-Verbose "Disabling Forms Based Authentication for ECP on the Default Web Site..."
		Set-ECPVirtualDirectory -Identity "$Server\ecp (Default Web Site)" -FormsAuthentication $false -WindowsAuthentication $true
	}

	# Reset IIS to affect the changes
	Write-Progress -Activity "Configuring EAC Virtual directory" -status "Resetting IIS" -percentComplete 99
	Write-Host "Restarting IIS to complete the configuration. This may take up to two minutes..."
	Invoke-Command -ScriptBlock {IISReset /NoForce /Timeout:120}
	Write-Host
}
